{% extends '@Contao/fragment/_container.html.twig' %}

{% block container %}
    {% trans_default_domain 'cms' %}

        <div class="divide-y divide-gray-200 dark:divide-gray-800">
            {% block main %}
            {% endblock %}
        </div>

{% endblock %}
