<div class="flex flex-col gap-4 rounded-2xl border border-rose-200 bg-rose-50 p-5 dark:border-rose-900/50 dark:bg-rose-900/15 sm:flex-row sm:items-center">
    <div class="flex size-11 flex-none items-center justify-center rounded-xl bg-rose-600/10 text-rose-700 dark:bg-rose-400/15 dark:text-rose-300">
        <twig:ux:icon name="lucide:users" class="size-6" />
    </div>
    <div class="flex-1 text-sm leading-5 text-rose-900 dark:text-rose-100">
        {# `key` is ApplicationForm::firstComeAvailability(): a season that works
           without a waiting list ('noWaitlist') must not promise one here. #}
        <b class="block font-semibold">{{ ('applicationForm.empty.' ~ key|default('waitlistFull') ~ '.title')|trans({}, 'cms') }}</b>
        <span class="block text-rose-900/80 dark:text-rose-100/85">{{ ('applicationForm.empty.' ~ key|default('waitlistFull') ~ '.text')|trans({}, 'cms') }}</span>
    </div>
    <div class="flex-none">
        {% include '@Contao/components/application_form/_save_calendar_button.html.twig' with { offer: offer } only %}
    </div>
</div>
