<div class="max-w-5xl mx-auto px-4 sm:px-6 lg:px-8">
    <div class="py-12 sm:py-16">
        <div class="shadow rounded overflow-hidden">
            {% embed '@FerienpassCore/Alert/error.html.twig' %}
                {% block headline %}
                    {{ 'error.401.title'|trans({}, 'cms') }}
                {% endblock %}
                {% block content %}
                    {{ 'error.401.text'|trans({}, 'cms') }}
                {% endblock %}
            {% endembed %}
        </div>
    </div>
</div>