<?php

declare(strict_types=1);

/*
 * This file is part of the Ferienpass package.
 *
 * (c) Richard Henkenjohann <richard@ferienpass.online>
 *
 * For more information visit the project website <https://ferienpass.online>
 * or the documentation under <https://docs.ferienpass.online>.
 */

// For the task options
use Contao\Controller;

Controller::loadLanguageFile('EditionTask');

$GLOBALS['TL_LANG']['tl_content']['ferienpass_task_condition'][0] = 'Only show in';
$GLOBALS['TL_LANG']['tl_content']['ferienpass_task_condition'][1] = 'Only show the content element if this task is active.';
$GLOBALS['TL_LANG']['tl_content']['ferienpass_task_condition_inverted'][0] = '…if not active';
$GLOBALS['TL_LANG']['tl_content']['ferienpass_task_condition_inverted'][1] = 'Do NOT show the content element if the selected task is active.';
$GLOBALS['TL_LANG']['tl_content']['cvaSize'][0] = 'Größe';
$GLOBALS['TL_LANG']['tl_content']['cvaSize'][1] = 'Das Element in der Größe verändern';
$GLOBALS['TL_LANG']['tl_content']['cvaPosition'][0] = 'Position/Ausrichtung';
$GLOBALS['TL_LANG']['tl_content']['cvaPosition'][1] = 'Das Element in der Ausrichtung verändern';
$GLOBALS['TL_LANG']['tl_content']['cvaButtonStyle'][0] = 'Stil';
$GLOBALS['TL_LANG']['tl_content']['cvaButtonStyle'][1] = 'Den Link im Aussehen verändern';
$GLOBALS['TL_LANG']['tl_content']['persons_legend'] = 'Personen';
$GLOBALS['TL_LANG']['tl_content']['persons'][0] = 'Personen';
$GLOBALS['TL_LANG']['tl_content']['persons_']['name'][0] = 'Name';
$GLOBALS['TL_LANG']['tl_content']['persons_']['description'][0] = 'Untertitel';

$GLOBALS['TL_LANG']['tl_content']['cva']['size']['sm'] = 'Klein';
$GLOBALS['TL_LANG']['tl_content']['cva']['size']['md'] = 'Normal';
$GLOBALS['TL_LANG']['tl_content']['cva']['size']['lg'] = 'Groß';
$GLOBALS['TL_LANG']['tl_content']['cva']['size']['xl'] = 'Extragroß';
$GLOBALS['TL_LANG']['tl_content']['cva']['position']['left'] = 'Links';
$GLOBALS['TL_LANG']['tl_content']['cva']['position']['center'] = 'Mitte';
$GLOBALS['TL_LANG']['tl_content']['cva']['position']['right'] = 'Rechts';
$GLOBALS['TL_LANG']['tl_content']['cva']['buttonStyle']['primary'] = 'Normal';
$GLOBALS['TL_LANG']['tl_content']['cva']['buttonStyle']['secondary'] = 'Zurückhaltend';
