<turbo-frame id="modal" class="flex h-full overflow-hidden">
    <div class="max-h-full flex flex-col {{ not spaceless|default ? 'p-4 md:p-8' }}">
        {{ block('modalContent') }}
    </div>
</turbo-frame>
