<?php

declare(strict_types=1);

/*
 * This file is part of the Ferienpass package.
 *
 * (c) Richard Henkenjohann <richard@ferienpass.online>
 *
 * For more information visit the project website <https://ferienpass.online>
 * or the documentation under <https://docs.ferienpass.online>.
 */

namespace Ferienpass\CmsBundle\Components;

use Ferienpass\CoreBundle\Entity\Offer\OfferInterface;
use Symfony\UX\TwigComponent\Attribute\AsTwigComponent;

/**
 * Offer card. Wishlist add/remove happens entirely client-side via the
 * `ferienpass/cms-wishlists` Stimulus controller (data lives in localStorage,
 * sharable as `/merkliste/<ids>?liste=<uuid>&liste_name=<name>`).
 */
#[AsTwigComponent(template: '@Contao/components/offer_list_item.html.twig')]
class OfferListItem
{
    public OfferInterface $item;
}
