<div {{ attributes.defaults(stimulus_controller('ferienpass/cms-flash-message', { url: path('cms_flash_message') })) }} aria-live="assertive" class="pointer-events-none fixed inset-0 flex items-end px-4 py-6 sm:items-start sm:p-6">
    <div class="flex w-full flex-col items-center space-y-4 sm:items-end" id="notifications">

    </div>
</div>
