{% extends '@Contao/fragment/_container.html.twig' %}

{% block container %}

    <div>
        <turbo-frame id="modal">
            <twig:Cms:CheckPayment payment="{{ payment }}"/>
        </turbo-frame>
    </div>

{% endblock %}
