<?php

declare(strict_types=1);

/*
 * This file is part of the Ferienpass package.
 *
 * (c) Richard Henkenjohann <richard@ferienpass.online>
 *
 * For more information visit the project website <https://ferienpass.online>
 * or the documentation under <https://docs.ferienpass.online>.
 */

namespace Ferienpass\CmsBundle\Tests\Message;

use Ferienpass\CmsBundle\Message\LoginLinkRequested;
use PHPUnit\Framework\TestCase;

final class LoginLinkRequestedTest extends TestCase
{
    public function testGetters(): void
    {
        $msg = new LoginLinkRequested('user-uuid', 'https://example.com/login_link?hash=abc');

        self::assertSame('user-uuid', $msg->getUserUuid());
        self::assertSame('https://example.com/login_link?hash=abc', $msg->getLoginLink());
        self::assertNotEmpty($msg->getRelated());
    }
}
