{% apply trim %}
    {% if begin and end %}
        {% if begin|date('Ymd') == end|date('Ymd') %}
            {% if noTime %}
                {{ begin|format_datetime(pattern='E, ', locale: locale) }}
                {{ begin|format_datetime(pattern='dd.MM.', locale: locale) }}
            {% else %}
                {{ begin|format_datetime(pattern='E, ', locale: locale) }}
                {{ begin|format_datetime(pattern='dd.MM. HH:mm', locale: locale) ~ ' – ' ~ end|format_datetime(pattern='HH:mm', locale: locale) }}
            {% endif %}
        {% else %}
            {{ begin|format_datetime(pattern='E, dd.MM. HH:mm', locale: locale) ~' – ' ~ end|format_datetime(pattern='E, dd.MM. HH:mm', locale: locale) }}
        {% endif %}
    {% endif %}
{% endapply %}
