<span class="flex items-center space-x-1">
    {% if attendance.offer.cancelled %}
        <twig:Cms:Badge label="applicationList.status.cancelled" :size="size" :class="class ~ ' text-red-700 bg-red-50 ring-red-600/15 dark:text-red-400 dark:bg-red-400/10 dark:ring-red-400/20'" />
        {% set emoji_code = 'applicationList.emoji.cancelled'|trans({}, 'cms') %}
        {% if emoji and emoji_code %}
            <span class="text-base">{{ emoji_code|emojify }}</span>
        {% endif %}
    {% elseif attendance.withdrawn %}
        <twig:Cms:Badge label="applicationList.status.withdrawn" :size="size" :class="class ~ ' text-red-700 bg-red-50 ring-red-600/15 dark:text-red-400 dark:bg-red-400/10 dark:ring-red-400/20'" />
        {% set emoji_code = 'applicationList.emoji.withdrawn'|trans({}, 'cms') %}
        {% if emoji and emoji_code %}
            <span class="text-base">{{ emoji_code|emojify }}</span>
        {% endif %}
    {% elseif attendance.emailUnconfirmed %}
        <twig:Cms:Badge label="applicationList.status.emailUnconfirmed" :size="size" :class="class ~ ' text-amber-700 bg-amber-50 ring-amber-600/15 dark:text-amber-400 dark:bg-amber-400/10 dark:ring-amber-400/20'" />
        {% set emoji_code = 'applicationList.emoji.emailUnconfirmed'|trans({}, 'cms') %}
        {% if emoji and emoji_code %}
            <span class="text-base">{{ emoji_code|emojify }}</span>
        {% endif %}
    {% elseif attendance.awaitingConsents %}
        <twig:Cms:Badge label="applicationList.status.consentsOutstanding" :size="size" :class="class ~ ' text-amber-700 bg-amber-50 ring-amber-600/15 dark:text-amber-400 dark:bg-amber-400/10 dark:ring-amber-400/20'" />
        {% set emoji_code = 'applicationList.emoji.consentsOutstanding'|trans({}, 'cms') %}
        {% if emoji and emoji_code %}
            <span class="text-base">{{ emoji_code|emojify }}</span>
        {% endif %}
    {% elseif attendance.isWaiting or attendance.stash or (attendance.offer.edition and not attendance.offer.edition.activeTasks('allocation').isEmpty) %}
        <twig:Cms:Badge label="applicationList.status.waitingForAllocation" :size="size" :class="class ~ ' text-gray-700 bg-gray-50 ring-gray-600/15 dark:text-gray-400 dark:bg-gray-400/10 dark:ring-gray-400/20'" />
        {% set emoji_code = 'applicationList.emoji.waitingForAllocation'|trans({}, 'cms') %}
        {% if emoji and emoji_code %}
            <span class="text-sm">{{ emoji_code|emojify }}</span>
        {% endif %}
    {% elseif attendance.unfulfilled %}
        <twig:Cms:Badge label="applicationList.status.noPlaceReceived" :size="size" :class="class ~ ' text-red-700 bg-red-50 ring-red-600/15 dark:text-red-400 dark:bg-red-400/10 dark:ring-red-400/20'" />
        {% set emoji_code = 'applicationList.emoji.unfulfilled'|trans({}, 'cms') %}
        {% if emoji and emoji_code %}
            <span class="text-base">{{ emoji_code|emojify }}</span>
        {% endif %}
    {% elseif attendance.rejected %}
        <twig:Cms:Badge label="applicationList.status.rejected" :size="size" :class="class ~ ' text-red-700 bg-red-50 ring-red-600/15 dark:text-red-400 dark:bg-red-400/10 dark:ring-red-400/20'" />
        {% set emoji_code = 'applicationList.emoji.rejected'|trans({}, 'cms') %}
        {% if emoji and emoji_code %}
            <span class="text-base">{{ emoji_code|emojify }}</span>
        {% endif %}
    {% elseif attendance.confirmed %}
        <twig:Cms:Badge label="applicationList.status.participates" :size="size" :class="class ~ ' text-green-700 bg-green-50 ring-green-600/15 dark:text-green-400 dark:bg-green-400/10 dark:ring-green-400/20'" />
        {% set emoji_code = 'applicationList.emoji.participates'|trans({}, 'cms') %}
        {% if emoji and emoji_code %}
            <span class="text-base">{{ emoji_code|emojify }}</span>
        {% endif %}
    {% elseif attendance.waitlisted %}
        <twig:Cms:Badge label="applicationList.status.waitlisted" :size="size" :class="class ~ ' text-yellow-700 bg-yellow-50 ring-yellow-600/15 dark:text-yellow-400 dark:bg-yellow-400/10 dark:ring-yellow-400/20'" />
        {% set emoji_code = 'applicationList.emoji.waitlisted'|trans({}, 'cms') %}
        {% if emoji and emoji_code %}
            <span class="text-base">{{ emoji_code|emojify }}</span>
        {% endif %}
    {% endif %}
</span>
