{% extends '@Contao/fragment/reset_password/_base.html.twig' %}

{% block content %}

    <h3 class="text-xl">{{ 'resetPassword.request.title'|trans({}, 'cms') }}</h3>

    <p class="mt-2 text-sm leading-5 text-gray-600 dark:text-gray-200 max-w">{{ 'resetPassword.request.text'|trans({}, 'cms') }}</p>

    <div class="mt-8">

        {{ form_start(form) }}
        <div class="space-y-6">
            {% for widget in form %}
                {{ form_row(widget) }}
            {% endfor %}
        </div>
        {{ form_end(form) }}

    </div>

    <div class="mt-6">
        {% include '@FerienpassAdmin/components/back-link.html.twig' with {uri: '/'} %}
    </div>

{% endblock %}
