{% set wrapper_attributes = attrs()
    .addClass('max-w-5xl mx-auto px-4 sm:px-6 lg:px-8')
    .mergeWith(wrapper_attributes|default) %}

{% set container_attributes = attrs()
    .addClass('py-12 space-y-6 text-black dark:text-gray-50')
    .mergeWith(container_attributes|default) %}

{% block wrapper %}

    <div {{ wrapper_attributes }}>

        {% block container %}

            <div {{ container_attributes }}>
                {%- block inner %}
                    {% block content %}
                        {{ elements|join|raw }}
                    {% endblock %}
                {% endblock -%}
            </div>

        {% endblock -%}

    </div>
{% endblock %}
