<div class="space-y-12">

    <div class="text-xl text-gray-500 dark:text-gray-300">
        <h2 class="leading-8 mb-2 font-bold text-3xl text-gray-900 dark:text-white"><span class="font-light">{{ 'registrationWelcomeSteps.fotoeinwilligung.titlePrefix'|trans({}, 'cms') }}</span><br>{{ 'registrationWelcomeSteps.fotoeinwilligung.title'|trans({}, 'cms') }}
        </h2>

        <p>{{ 'registrationWelcomeSteps.fotoeinwilligung.text'|trans({}, 'cms') }}</p>
    </div>

    <twig:Cms:Consents />

    <div class="mt-12 flex items-center justify-center">
        <button type="submit"
                data-action="live#action:prevent"
                data-live-action-param="continue"
                class="rounded-md bg-primary-600 px-4 py-2.5 text-base font-semibold text-white shadow-sm hover:bg-primary-500 focus-visible:outline focus-visible:outline-2 focus-visible:outline-offset-2 focus-visible:outline-primary-600">
            {{ 'registrationWelcomeSteps.fotoeinwilligung.submit'|trans({}, 'cms') }}
        </button>
    </div>

</div>
