<?php

declare(strict_types=1);

/*
 * This file is part of the Ferienpass package.
 *
 * (c) Richard Henkenjohann <richard@ferienpass.online>
 *
 * For more information visit the project website <https://ferienpass.online>
 * or the documentation under <https://docs.ferienpass.online>.
 */

namespace Ferienpass\CmsBundle\Tests\Message;

use Ferienpass\CmsBundle\Message\PasswordLinkCreated;
use Ferienpass\CmsBundle\Message\ResetPassword;
use PHPUnit\Framework\TestCase;

final class ResetPasswordTest extends TestCase
{
    public function testGetEmailReturnsEmail(): void
    {
        $msg = new ResetPassword('user@example.com');

        self::assertSame('user@example.com', $msg->getEmail());
    }

    public function testPasswordLinkCreatedGetters(): void
    {
        $msg = new PasswordLinkCreated('user-uuid', 'token-abc');

        self::assertSame('user-uuid', $msg->getUserUuid());
        self::assertSame('token-abc', $msg->getToken());
    }
}
