{% if size == 'xs' %}
    {% set class = class ~ ' px-1.5 py-0.5 text-xs' %}
{% elseif size == 'sm' %}
    {% set class = class ~ ' px-2 py-0.5 text-sm' %}
{% elseif size == 'base' %}
    {% set class = class ~ ' px-2.5 py-1 text-base' %}
{% endif %}

<span class="rounded-md whitespace-nowrap mt-0.5 font-medium ring-1 ring-inset {{ class|trim }}">
    {{ label|trans({}, 'cms') }}
</span>
