{% extends '@Contao/fragment/reset_password/_base.html.twig' %}

{% block content %}

    <h3 class="text-xl">{{ 'resetPassword.reset.title'|trans({}, 'cms') }}</h3>

    <p class="mt-2 text-sm leading-5 text-gray-600 dark:text-gray-200 max-w">{{ 'resetPassword.reset.text'|trans({}, 'cms') }}</p>

    {{ form_start(form) }}
    <div class="space-y-6">
        {{ form_row(form.plainPassword) }}
        {{ form_row(form.submit) }}
    </div>
    {{ form_end(form) }}

{% endblock %}
