<div class="user-navigation user-navigation--mobile" data-testid="user-navigation-mobile">
    <span class="user-navigation__initials" translate="no|pii">{{ user.firstname|first|upper ~ user.lastname|first|upper }}</span>
    <span class="user-navigation__name" translate="no|pii">{{ user.firstname ~ ' ' ~ user.lastname }}</span>
    <span class="user-navigation__email" translate="no|pii">{{ user.email }}</span>
</div>
