<div class="user-navigation user-navigation--dropdown" data-testid="user-navigation-dropdown">
    <span class="user-navigation__name" translate="no|pii">{{ user.firstname ~ ' ' ~ user.lastname }}</span>
    <span class="user-navigation__email" translate="no|pii">{{ user.email }}</span>
</div>
