<?php

declare(strict_types=1);

/*
 * This file is part of the Ferienpass package.
 *
 * (c) Richard Henkenjohann <richard@ferienpass.online>
 *
 * For more information visit the project website <https://ferienpass.online>
 * or the documentation under <https://docs.ferienpass.online>.
 */

namespace Ferienpass\CmsBundle\Fragment;

class FragmentReference extends \Contao\CoreBundle\Fragment\Reference\FragmentReference
{
    final public const string TAG_NAME = 'ferienpass.fragment';
}
