{% extends '@Contao/fragment/_container.html.twig' %}

{% block container %}

    <div class="max-w-5xl mx-auto px-4 sm:px-6 lg:px-8 py-12 sm:py-24">

            <div class="text-center">
                <p class="text-base sm:text-xl font-semibold text-primary">{{ 'accountUnsubscribed.subtitle'|trans({}, 'cms') }}</p>
                <h1 class="mt-4 text-5xl font-semibold tracking-tight text-balance text-gray-900 dark:text-white sm:text-6xl">{{ 'accountUnsubscribed.title'|trans({}, 'cms') }}</h1>
                <p class="mt-6 text-lg font-medium text-pretty text-gray-500 dark:text-white/70 sm:text-xl/8">{{ 'accountUnsubscribed.text'|trans({email: email, date: unsubscribed}, 'cms') }}</p>
                {{ form_start(actions) }}
                    <div class="mt-10 flex items-center justify-center gap-x-6">
                    {{ form_widget(actions.unblock) }}
                    {{ form_widget(actions.delete, {'attr': {'class': 'bg-red-600 hover:bg-red-500 '}}) }}
                    <a href="/" class="text-sm font-semibold text-gray-900 dark:text-white/90">{{ 'accountUnsubscribed.backToHome'|trans({}, 'cms') }} <span aria-hidden="true">&rarr;</span></a>
                    </div>
                {{ form_end(actions) }}
            </div>

    </div>

{% endblock %}
