{% extends '@Contao/fragment/user_account/_base.html.twig' %}

{% block main %}
    <div class="py-16 border-t border-gray-200 dark:border-gray-800">
        <div class="mb-10">
            <h2 class="text-base/7 font-semibold text-gray-900 dark:text-gray-50">{{ 'userAccount.dataUsage.title'|trans({}, 'cms') }}</h2>
            <p class="mt-1 max-w-2xl text-sm/6 text-gray-500 dark:text-gray-400">
                {{ 'userAccount.dataUsage.text'|trans({}, 'cms') }}
            </p>
        </div>

        <twig:Cms:DataUsage />
    </div>
{% endblock %}
