<?php

declare(strict_types=1);

/*
 * This file is part of the Ferienpass package.
 *
 * (c) Richard Henkenjohann <richard@ferienpass.online>
 *
 * For more information visit the project website <https://ferienpass.online>
 * or the documentation under <https://docs.ferienpass.online>.
 */

namespace Ferienpass\CmsBundle\Components;

use Ferienpass\CoreBundle\ApplicationSystem\ApplicationSystemInterface;
use Ferienpass\CoreBundle\Entity\OfferCategory;
use Symfony\Component\Form\FormView;
use Symfony\UX\TwigComponent\Attribute\AsTwigComponent;

#[AsTwigComponent(template: '@Contao/components/filter.html.twig')]
class Filter
{
    public FormView $form;

    public ?ApplicationSystemInterface $applicationSystem = null;

    /** @var list<OfferCategory>|array<int, OfferCategory> */
    public array $categories = [];

    public int $totalCount = 0;
}
