{% if offer.minAge and offer.maxAge %}
    {{ offer.minAge ~ ' - ' ~ offer.maxAge ~' ' ~ 'offer.years'|trans({}, 'cms') }}
{% elseif offer.minAge %}
    {{ 'offer.from'|trans({}, 'cms') ~ ' ' ~ offer.minAge ~ ' ' ~ 'offer.years'|trans({}, 'cms') }}
{% elseif offer.maxAge %}
    {{ 'offer.until'|trans({}, 'cms') ~ ' ' ~ offer.maxAge ~ ' ' ~ 'offer.years'|trans({}, 'cms') }}
{% else %}
    {{ 'offer.allChildren'|trans({}, 'cms') }}
{% endif %}
