{# Onboarding page header. Expects `kicker`, `title`, `lede`. #}
<header class="mb-6">
    <span class="mb-2.5 inline-flex items-center gap-2 text-[11px] font-semibold uppercase tracking-[0.14em] text-primary-700 dark:text-primary-300">
        <span class="inline-block h-px w-5 bg-primary-600"></span>
        {{ kicker }}
    </span>
    <h1 class="mb-2 text-3xl font-bold leading-tight tracking-tight text-gray-900 dark:text-white sm:text-4xl">{{ title }}</h1>
    <p class="max-w-[56ch] text-base leading-relaxed text-gray-600 dark:text-gray-300">{{ lede }}</p>
</header>
