{% if token %}
    <div data-controller="ferienpass--cms-mapbox-consent-bar"
         class="hidden fixed inset-x-0 bottom-0 z-40 border-t border-gray-200 bg-white/95 shadow-[0_-8px_24px_-16px_rgba(0,0,0,0.35)] backdrop-blur dark:border-gray-700 dark:bg-gray-900/95">
        <div class="mx-auto flex max-w-3xl flex-col gap-3 px-4 py-4 sm:flex-row sm:items-center sm:justify-between">
            <div class="min-w-0 text-[13px] leading-relaxed text-gray-600 dark:text-gray-300">
                <p>{{ 'onboarding.address.consent.text'|trans({}, 'cms') }}</p>
                <button type="button"
                        data-action="ferienpass--cms-mapbox-consent-bar#toggleInfo"
                        class="mt-1 text-xs font-medium text-primary-600 hover:underline dark:text-primary-400">
                    {{ 'offerDetails.mapboxConsent.infoButton'|trans({}, 'cms') }}
                </button>
                <div data-ferienpass--cms-mapbox-consent-bar-target="info" class="mt-2 hidden max-w-2xl text-xs text-gray-500 dark:text-gray-400">
                    {{ 'offerDetails.mapboxConsent.infoText'|trans({}, 'cms')|nl2br }}
                </div>
            </div>
            <twig:Cms:Button variant="primary" size="sm"
                    data-action="ferienpass--cms-mapbox-consent-bar#accept"
                    class="flex-none whitespace-nowrap">
                {{ 'onboarding.address.consent.button'|trans({}, 'cms') }}
            </twig:Cms:Button>
        </div>
    </div>
{% endif %}
