<twig:Turbo:Stream:Prepend target="#flash-banners">
    <div class="bg-blue-900 text-center py-4 lg:px-4">
        <div class="p-2 bg-blue-800 items-center text-blue-100 leading-none lg:rounded-full flex lg:inline-flex"
             role="alert">
            {% if href|default %}
            <a href="{{ href }}">
                {% endif %}

                {% if headline %}
                    <span class="flex rounded-full bg-blue-500 uppercase px-2 py-1 text-xs font-bold mr-1">{{ headline|trans }}</span>
                {% endif %}

                <span class="ml-2 font-semibold mr-2 text-left flex-auto">{{ text|trans }}</span>

                {% if href|default %}
                    <twig:ux:icon name="lucide:arrow-right" class="inline-block fill-current opacity-75 h-4 w-4" />
                {% endif %}

                {% if href|default %}
            </a>
            {% endif %}

        </div>
    </div>
</twig:Turbo:Stream:Prepend>
