{% extends '@Contao/fragment/_container.html.twig' %}

{% block container %}

    {% embed '@Contao/fragment/_modalBase.html.twig' %}
        {% block modalContent %}

            <div class="flex-1 overflow-y-scroll sm:flex sm:items-start">
                <div class="mx-auto flex-shrink-0 flex items-center justify-center h-12 w-12 rounded-full bg-blue-100 dark:bg-blue-600/70 sm:mx-0 sm:h-10 sm:w-10">
                    <twig:ux:icon name="lucide:refresh-cw" class="block h-6 w-6 text-blue-600 dark:text-blue-100/90" />
                </div>
                <div class="mt-3 text-center sm:mt-0 sm:ml-4 sm:text-left">
                    <h3 class="text-lg leading-6 font-medium text-gray-900 dark:text-gray-100"
                        id="modal-headline">{{ 'applicationsPrioritize.title'|trans({}, 'cms') }}</h3>
                    <div class="mt-2">
                        <p class="text-sm leading-5 text-gray-500 dark:text-gray-300">
                            {{ 'applicationsPrioritize.text'|trans({}, 'cms') }}
                        </p>

                        <twig:Cms:ApplicationsPrioritize class="mt-4 text-left" edition="{{ edition }}" participant="{{ participant }}" applicationSystem="{{ applicationSystem }}" />

                    </div>
                </div>
            </div>
            <div class="mt-5 sm:mt-4 sm:flex sm:flex-row-reverse">
                {# todo: make it a form submit, than render turbo-stream updates (update list, prepend notification) #}
                <form method="dialog">
                    <button class="mt-3 inline-flex w-full justify-center rounded-md bg-white px-3 py-2 text-sm font-semibold text-gray-900 shadow-sm ring-1 ring-inset ring-gray-300 hover:bg-gray-50 sm:mt-0 sm:w-auto">
                        {{ 'userAccount_close_account.modal.close'|trans({}, 'cms') }}
                    </button>
                </form>
            </div>
        {% endblock %}
    {% endembed %}

{% endblock %}
