{% extends '@Contao/fragment/reset_password/_base.html.twig' %}

{% block content %}

    <h3 class="text-xl">{{ 'resetPassword.checkEmail.title'|trans({}, 'cms') }}</h3>

    <p class="mt-2 text-gray-600 dark:text-gray-200 leading-tight">
        {{ 'resetPassword.checkEmail.text'|trans({}, 'cms') }}
        {{ 'resetPassword.checkEmail.linkExpiration'|trans({}, 'cms') }}
        {{ resetToken.expirationMessageKey|trans(resetToken.expirationMessageData, 'ResetPasswordBundle') }}.
    </p>
    <p class="mt-2 text-gray-500 dark:text-gray-300 text-sm">{{ 'resetPassword.checkEmail.noEmail'|trans({}, 'cms') }} <a
                class="underline hover:no-underline" href="{{ path('cms_lost_password') }}">{{ 'resetPassword.checkEmail.retry'|trans({}, 'cms') }}</a>.</p>

    <div class="mt-6">
        {% include '@FerienpassAdmin/components/back-link.html.twig' with {uri: '/'} %}
    </div>

{% endblock %}