<section class="max-w-5xl mx-auto px-4 sm:px-6 lg:px-8">

    <h1 class="mb-6 text-2xl/7 font-bold text-gray-900 sm:truncate sm:text-3xl sm:tracking-tight dark:text-white">Ihr Nutzerkonto</h1>

    <twig:Cms:Tabs :items="items" />
</section>
