{% extends '@Contao/fragment/_container.html.twig' %}

{% block container %}

    <div class="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 pt-12">
        <div class="prose dark:prose-invert max-w-none text-gray-600 dark:text-gray-200">
            {{ (edition.welcomeText ?? '')|markdown_to_html|encodeEmail }}
        </div>
    </div>

{% endblock %}
