<?php

declare(strict_types=1);

/*
 * This file is part of the Ferienpass package.
 *
 * (c) Richard Henkenjohann <richard@ferienpass.online>
 *
 * For more information visit the project website <https://ferienpass.online>
 * or the documentation under <https://docs.ferienpass.online>.
 */

namespace Ferienpass\CmsBundle\Controller\Fragment;

use Ferienpass\CoreBundle\Controller\AbstractPrivateFragmentController;
use Symfony\Component\HttpFoundation\Response;

class RegistrationWelcomeController extends AbstractPrivateFragmentController
{
    public function __invoke(): Response
    {
        return $this->render('@Contao/fragment/registration_welcome.html.twig');
    }
}
