{% block live_collection_button_add_widget %}
    <button type="{{ type|default('button') }}" id="{{ id|default('') }}" name="{{ full_name|default('') }}"{% for attrname, attrvalue in attr|default({}) %}{% if attrvalue is not none and attrvalue is not same as(false) and attrname != 'class' %} {{ attrname }}="{{ attrvalue }}"{% endif %}{% endfor %}
            class="inline-flex items-center gap-2 rounded-md border border-gray-300 bg-white px-3 py-2 text-sm font-semibold text-gray-700 shadow-xs transition hover:border-primary-300 hover:bg-primary-50 hover:text-primary-700 dark:border-gray-600 dark:bg-gray-800 dark:text-gray-200 dark:hover:bg-primary-600/10">
        <svg class="h-4 w-4 text-primary-600" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2.2" stroke-linecap="round" stroke-linejoin="round"><path d="M12 5v14"/><path d="M5 12h14"/></svg>
        {{ 'participants.addSomeone'|trans({}, 'cms') }}
    </button>
{% endblock %}

{% block live_collection_button_delete_widget %}
    <button type="{{ type|default('button') }}" id="{{ id|default('') }}" name="{{ full_name|default('') }}"{% for attrname, attrvalue in attr|default({}) %}{% if attrvalue is not none and attrvalue is not same as(false) and attrname != 'class' %} {{ attrname }}="{{ attrvalue }}"{% endif %}{% endfor %}
            class="inline-flex items-center gap-1.5 rounded-lg px-2.5 py-1.5 text-[12px] font-semibold text-gray-400 transition hover:bg-red-50 hover:text-red-600 dark:hover:bg-red-900/30">
        <svg class="h-3.5 w-3.5" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path d="M3 6h18"/><path d="M8 6V4a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v2"/><path d="m6 6 1 14a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2l1-14"/></svg>
        {{ 'onboarding.children.remove'|trans({}, 'cms') }}
    </button>
{% endblock %}
