<twig:Turbo:Stream:Prepend target="#notifications">
    <div class="max-w-5xl mx-auto px-4 sm:px-6 lg:px-8 py-4 lg:py-6">
        {% include "@FerienpassCore/Alert/#{type}.html.twig" with {
            headline: headline ? headline|trans : null,
            message:  text ? text|trans : ''
        } %}
    </div>
</twig:Turbo:Stream:Prepend>
