<?php

declare(strict_types=1);

/*
 * This file is part of the Ferienpass package.
 *
 * (c) Richard Henkenjohann <richard@ferienpass.online>
 *
 * For more information visit the project website <https://ferienpass.online>
 * or the documentation under <https://docs.ferienpass.online>.
 */

namespace Ferienpass\CmsBundle\Message;

use Ferienpass\CoreBundle\Message\LoggableMessageInterface;

/**
 * A password reset was requested for an e-mail address with no account.
 *
 * The requester is informed (by mail) that no account is linked to the address,
 * so they can retry with the right one. The address is unverified input, hence
 * no {@see \Ferienpass\CoreBundle\Entity\User} relation.
 */
class PasswordResetHelpRequested implements LoggableMessageInterface
{
    public function __construct(private readonly string $email)
    {
    }

    public function getEmail(): string
    {
        return $this->email;
    }

    public function getRelated(): array
    {
        return [];
    }
}
