<?php

declare(strict_types=1);

/*
 * This file is part of the Ferienpass package.
 *
 * (c) Richard Henkenjohann <richard@ferienpass.online>
 *
 * For more information visit the project website <https://ferienpass.online>
 * or the documentation under <https://docs.ferienpass.online>.
 */

$GLOBALS['TL_LANG']['tl_page']['edition'][0] = 'Saison';
$GLOBALS['TL_LANG']['tl_page']['edition'][1] = 'Wenn keine Auswahl getroffen wird, werden die Angebote der aktuellen Saision angezeigt.';
$GLOBALS['TL_LANG']['tl_page']['image_legend'] = 'Seitenbild';
$GLOBALS['TL_LANG']['tl_page']['pageImage'][0] = 'Seitenbild';
$GLOBALS['TL_LANG']['tl_page']['pageImage'][1] = 'Das Bild wird für diese Seite angezeigt. Wenn Sie hier ein Bild auswählen, wird das Bild vom Webseitenstartpunkt überschrieben.';
