'use strict';
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { Controller } from '@hotwired/stimulus';
export default class default_1 extends Controller {
    open() {
        if (this.hasModalTarget) {
            this.modalTarget.style.display = 'flex';
        }
        if (this.hasNameTarget) {
            this.nameTarget.value = '';
            this.nameTarget.focus();
        }
    }
    close() {
        if (this.hasModalTarget) {
            this.modalTarget.style.display = 'none';
        }
    }
    create() {
        return __awaiter(this, void 0, void 0, function* () {
            const name = this.hasNameTarget ? this.nameTarget.value.trim() : '';
            try {
                yield fetch(this.nameUrlValue, {
                    method: 'POST',
                    headers: { 'Content-Type': 'application/json', 'X-Requested-With': 'XMLHttpRequest' },
                    body: JSON.stringify({ name }),
                });
            }
            catch (e) {
            }
            this.close();
            if (this.hasWebauthnButtonTarget) {
                this.webauthnButtonTarget.click();
            }
        });
    }
    reload() {
        window.location.reload();
    }
}
default_1.values = {
    nameUrl: String,
};
default_1.targets = ["modal", "name", "webauthnButton"];
