{% extends '@Contao/content_element/text.html.twig' %}

{% set prose = html_cva(
    base = 'prose dark:prose-invert',
    variants = {
        size: {
            sm: 'prose-sm',
            md: 'prose-sm lg:prose-base',
            lg: 'lg:prose-lg',
            xl: 'prose-lg lg:prose-xl',
        }
    },
    defaultVariant = {
        size: 'lg',
    }
) %}

{% set attributes = attrs(attributes|default).addClass(prose.apply({size: data.cvaSize})) %}
