{% extends '@Contao/fragment/_container.html.twig' %}

{% block container %}

    <section class="grid sm:grid-cols-2 lg:grid-cols-3 gap-6" aria-label="{{ 'offerList.ariaLabel'|trans({}, 'cms') }}">
        {% for item in items %}
            <twig:Cms:OfferListItem item="{{ item }}" key="{{ item.id }}"/>
        {% endfor %}
    </section>

{% endblock %}
